@@ -9,7 +9,6 @@ from lager.core import (
     LOG,
     _change_activation,
     _core,
-    _dynamic_level,
     _find_iter,
     _log,
     _options,
@@ -62,12 +61,12 @@ __all__ = (
     "log",
     "ln",
     "LN",
+    "reset",
     #############
     ## HOISTED ##
     #############
     "_change_activation",
     "_core",
-    "_dynamic_level",
     "_find_iter",
     "_log",
     "_options",
